# TOPSIS



Submitted By: **Ishaan Singh Sohi 102003689**


<br>

## How to use this package:

Topsis-Ishaan-102003689  can be run as follows:



### In Command Prompt
```
>> python 102003689.py 102003689-data.csv "1,1,1,1,1" "+,+,-,+,+" 102003689-result.csv
```
